# Linux driver files for our Sakamoto (SHARP MX 3071) printer

This repository contains PPD files for Linux & Mac OS. Here is a quick overview
of the files:

- `SHARP-originals/SHarp3071PS.ppd`:
The original PPD file as downloaded from the [official SHARP website](https://www.sharp.de/cps/rde/xchg/de/hs.xsl/-/html/product-details-office-print.htm?product=MX3071)
- `linux.ppd`: The main Linux & MAC OS PPD file. If in doubt, use this. It is essentially a modified version of the original `Sharp3071PS.ppd` file, with the following changes:
  - Remove all unnecessary features, that is, everything but:
      - Color/BW selection
      - Page Size (only A4 & A3)
      - Page Type (only Normal paper & Thick paper)
      - Duplex/no Duplex
  - Add an account selection option. This is a custom text option (see [here](https://www.cups.org/doc/spec-ppd.html#OPTIONS)) under the "Printer Account" group. It adds the following PJL control option:
    ```
    @PJL SET SAKAMOTONAME = Useraccountname
    ```
    This option is recognized by PaperCut (see [here](https://www.papercut.com/support/resources/manuals/ng-mf/applicationserver/topics/printer-external-usernames.html)) and used to override the CUPS-provided username (which is most often the Linux user account name and thus wrong). Why not use the standard `@PJL SET USERNAME` option? Because CUPS often sets this to (once again) your Linux account name, and we didn't find a sensible way prevent CUPS from adding it.
- `driverless.ppd`: This is just the output of the command 
    ```
    driverless ipp://address-of-the-printer
    ```
    Generally not really useful, as you currently have no way of setting the username manually (aside from printing via command line), but might be useful in the future should we go driverless.
- `sakamoto_nofilter.ppd`: A modified version of `linux.ppd` which bypasses all filters. The normal `linux.ppd` file makes all files be converted into PostScript; this one doesn't. This is useful for the `normal_paper_backend` and `thick_paper_backend` queues, because by they will usually already receive filtered (be it by Windows and PCL or Linux and PPD) data. A second conversion might break things. However, this PPD is *not* for clients.